Look up predictor variable names from a fitted model
lookup.var.names.RdInternal function to get the predictor variable names used to fit a model, given its algorithm.
lookup.var.names.RdInternal function to get the predictor variable names used to fit a model, given its algorithm.